import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';

class NUIAppVersionItem extends NUIEnt<NUIAppVersionItem>{
  static const int STATUS_ACTIVE = 1;
  static const int STATUS_INACTIVE = 0;

  static const int LEVEL_NONE = -1;
  static const int LEVEL_NO_PROMPT = 0;
  static const int LEVEL_PROMPT = 1;
  static const int LEVEL_FORCE_UPDATE = 2;
  static const int LEVEL_HIDDEN = 3;
  static const int LEVEL_NOT_SUPPORTED = 4;

  String version;
  String platform;
  bool active;
  int updateLevel;
  int buildNumber;
  String downloadLink;
  String redirectLink;
  String title;
  String message;

  NUIAppVersionItem.empty();

  @override
  NUIEntMapper<NUIAppVersionItem> mapper() => NUIAppVersionItemEnt();
}
class NUIAppVersionItemEnt extends NUIEntMapper<NUIAppVersionItem>{
  @override
  String entityName() => "NUIAppVersionItem";

  @override
  List<NUIEntField> fields() =>  [
    NUIEntField<NUIAppVersionItem>(name: "version", type: NUIEntType.STRING, setter: (data, value) => data.version = value, getter: (data) => data.version),
    NUIEntField<NUIAppVersionItem>(name: "platform", type: NUIEntType.STRING, setter: (data, value) => data.platform = value, getter: (data) => data.platform),
    NUIEntField<NUIAppVersionItem>(name: "active", type: NUIEntType.BOOLEAN, setter: (data, value) => data.active = value, getter: (data) => data.active),
    NUIEntField<NUIAppVersionItem>(name: "updateLevel", type: NUIEntType.INTEGER, setter: (data, value) => data.updateLevel = value, getter: (data) => data.updateLevel),
    NUIEntField<NUIAppVersionItem>(name: "buildNumber", type: NUIEntType.INTEGER, setter: (data, value) => data.buildNumber = value, getter: (data) => data.buildNumber),
    NUIEntField<NUIAppVersionItem>(name: "downloadLink", type: NUIEntType.STRING, setter: (data, value) => data.downloadLink = value, getter: (data) => data.downloadLink),
    NUIEntField<NUIAppVersionItem>(name: "redirectLink", type: NUIEntType.STRING, setter: (data, value) => data.redirectLink = value, getter: (data) => data.redirectLink),
    NUIEntField<NUIAppVersionItem>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
    NUIEntField<NUIAppVersionItem>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
  ];

  @override
  NUIAppVersionItem newInstance() => NUIAppVersionItem.empty();
}

class NUIAppVersionResponse extends NUIEnt<NUIAppVersionResponse>{
  NUIAppVersionResponse.empty();
  List<NUIAppVersionItem> versions;

  @override
  NUIEntMapper<NUIAppVersionResponse> mapper() => NUIAppVersionResponseEnt();
}
class NUIAppVersionResponseEnt extends NUIEntMapper<NUIAppVersionResponse>{
  @override
  String entityName() => "NUIAppVersionResponse";

  @override
  List<NUIEntField> fields() => [
    NUIEntField<NUIAppVersionResponse>(name: "versions", type: NUIEntType.LIST_OBJECT, setter: (data, value) => data.versions = asListOfObjects(NUIAppVersionItemEnt(), value), getter: (data) => data.versions),
  ];

  @override
  NUIAppVersionResponse newInstance() => NUIAppVersionResponse.empty();
}

class IDialogTheme extends NUIEnt<IDialogTheme> {
  IDialogTheme.empty();
  IDialogTheme({
    this.accentColor,
    this.backgroundColor,
    this.textOnAccentColor,
    this.textOnBackgroundColor,
    this.textHighlightColor
  });

  String accentColor;
  String backgroundColor;
  String textOnAccentColor;
  String textOnBackgroundColor;
  String textHighlightColor;

  void copyFrom(IDialogTheme theme){
    if(isNullOrEmpty(accentColor)) accentColor = theme.accentColor;
    if(isNullOrEmpty(backgroundColor)) backgroundColor = theme.backgroundColor;
    if(isNullOrEmpty(textOnAccentColor)) textOnAccentColor = theme.textOnAccentColor;
    if(isNullOrEmpty(textOnBackgroundColor)) textOnBackgroundColor = theme.textOnBackgroundColor;
    if(isNullOrEmpty(textHighlightColor)) textHighlightColor = theme.textHighlightColor;
  }

  @override
  NUIEntMapper<IDialogTheme> mapper() => IDialogThemeEnt();
}
class IDialogThemeEnt extends NUIEntMapper<IDialogTheme>{
  @override
  String entityName() => "IDialogTheme";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<IDialogTheme>(name: "accentColor", type: NUIEntType.STRING, setter: (data, value) => data.accentColor = value, getter: (data) => data.accentColor),
      NUIEntField<IDialogTheme>(name: "backgroundColor", type: NUIEntType.STRING, setter: (data, value) => data.backgroundColor = value, getter: (data) => data.backgroundColor),
      NUIEntField<IDialogTheme>(name: "textOnAccentColor", type: NUIEntType.STRING, setter: (data, value) => data.textOnAccentColor = value, getter: (data) => data.textOnAccentColor),
      NUIEntField<IDialogTheme>(name: "textOnBackgroundColor", type: NUIEntType.STRING, setter: (data, value) => data.textOnBackgroundColor = value, getter: (data) => data.textOnBackgroundColor),
      NUIEntField<IDialogTheme>(name: "textHighlightColor", type: NUIEntType.STRING, setter: (data, value) => data.textHighlightColor = value, getter: (data) => data.textHighlightColor),
    ];
  }

  @override
  IDialogTheme newInstance() => IDialogTheme.empty();
}


class NUIAppVersionActionResponse extends NUIEnt<NUIAppVersionActionResponse>{
  NUIAppVersionActionResponse.empty();

  int action;
  String title;
  String description;
  String updateButton;
  String dismissButton;
  String imageLink;
  String newVersion;
  IDialogTheme colorTheme;

  @override
  NUIEntMapper<NUIAppVersionActionResponse> mapper() => NUIAppVersionActionResponseEnt();
}
class NUIAppVersionActionResponseEnt extends NUIEntMapper<NUIAppVersionActionResponse>{
  @override
  String entityName() => "NUIAppVersionActionResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIAppVersionActionResponse>(name: "action", type: NUIEntType.INTEGER, setter: (data, value) => data.action = value, getter: (data) => data.action),
      NUIEntField<NUIAppVersionActionResponse>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
      NUIEntField<NUIAppVersionActionResponse>(name: "description", type: NUIEntType.STRING, setter: (data, value) => data.description = value, getter: (data) => data.description),
      NUIEntField<NUIAppVersionActionResponse>(name: "updateButton", type: NUIEntType.STRING, setter: (data, value) => data.updateButton = value, getter: (data) => data.updateButton),
      NUIEntField<NUIAppVersionActionResponse>(name: "dismissButton", type: NUIEntType.STRING, setter: (data, value) => data.dismissButton = value, getter: (data) => data.dismissButton),
      NUIEntField<NUIAppVersionActionResponse>(name: "imageLink", type: NUIEntType.STRING, setter: (data, value) => data.imageLink = value, getter: (data) => data.imageLink),
      NUIEntField<NUIAppVersionActionResponse>(name: "newVersion", type: NUIEntType.STRING, setter: (data, value) => data.newVersion = value, getter: (data) => data.newVersion),
      NUIEntField<NUIAppVersionActionResponse>(name: "colorTheme", type: NUIEntType.OBJECT, setter: (data, value) => data.colorTheme = asObject(IDialogThemeEnt(), value), getter: (data) => data.colorTheme),
    ];
  }

  @override
  NUIAppVersionActionResponse newInstance() =>NUIAppVersionActionResponse.empty();
}