import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:iversioning/data/web/iversioning_json.dart';
import 'package:nui_animation/nui_button_animation.dart';
import 'package:nui_core/model/hex_color.dart';
import 'package:nui_core/ui/component/nui_app.dart';
import 'package:nui_core/ui/component/nui_column.dart';
import 'package:nui_core/ui/component/nui_dialog_widget.dart';
import 'package:nui_core/ui/nui_navigator.dart';
import 'package:nui_core/ui/styling/nui_box_decoration.dart';

void showIVersionPromptDialog(BuildContext context, NUIAppVersionActionResponse actionResponse){
  showNUIDialog(
      transition: PageTransition.SCALE,
      transitionDuration: Duration(milliseconds: 250),
      context: context,
      dismissible: false,
      content: (context) => IVersioningPromptDialog(actionResponse)
  );
}

class IVersioningPromptDialog extends StatelessWidget {
  IVersioningPromptDialog(this.actionResponse);
  final NUIAppVersionActionResponse actionResponse;

  void _updateClicked(BuildContext context){

  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async{
        //Disable closing of dialog if force update
        return actionResponse.action != NUIAppVersionItem.LEVEL_FORCE_UPDATE;
      },
      child: ListView(
        shrinkWrap: true,
        children: [
          Container(
            alignment: Alignment.center,
            margin: EdgeInsets.all(50),
            padding: EdgeInsets.only(left: 15, right: 15, top: 20, bottom: 15),
            decoration: BoxDecoration(
                color: Colors.white,
                borderRadius: BorderRadius.circular(15)
            ),
            child: NUIColumn(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.center,
              divider: Divider(height: 10, color: Colors.transparent),
              children: [
                Padding(
                  padding: EdgeInsets.only(left: 20, right: 20, top: 5, bottom: 20),
                  child: Text(actionResponse.title ?? "New App Version", style: getFont(context, size: 16, singleColor: HexColor(actionResponse.colorTheme?.textHighlightColor ?? "000000")), textAlign: TextAlign.center)
                ),
                Padding(
                  padding: EdgeInsets.only(left: 20, right: 20, bottom: 20),
                  child: Text(actionResponse.description ?? "Your app version is outdated.\nPlease update your app to the latest version.", style: getFont(context, size: 14, singleColor: HexColor(actionResponse.colorTheme?.textOnBackgroundColor ?? "000000")), textAlign: TextAlign.center)
                ),
                NUIBouncingAnimation(
                    scaleFactor: 0.3,
                    child: Container(
                        width: double.infinity,
                        padding: EdgeInsets.all(10),
                        alignment: Alignment.center,
                        decoration: NUIBoxDecoration(
                            color: HexColor(actionResponse.colorTheme?.accentColor ?? "000000"),
                            borderRadiusCircular: 10,
                            shadowOffset: Offset(1,1),
                            shadowColor: Colors.black12,
                            shadowRadius: 3
                        ),
                        child:Text(actionResponse.updateButton ?? "Update Software", style: getFont(context, size: 14, isBold: true, singleColor: HexColor(actionResponse.colorTheme?.textOnAccentColor ?? "ffffff")))
                    ),
                    onTap: (){
                      _updateClicked(context);
                    }
                ),
                actionResponse.action != NUIAppVersionItem.LEVEL_FORCE_UPDATE ? NUIBouncingAnimation(
                    scaleFactor: 0.3,
                    child: Container(
                      width: double.infinity,
                      padding: EdgeInsets.all(10),
                      alignment: Alignment.center,
                      decoration: NUIBoxDecoration(
                          color: Colors.transparent,
                          borderRadius: BorderRadius.circular(10)
                      ),
                      child: Text(actionResponse.dismissButton ?? "Maybe Later", style: getFont(context, size: 14, isBold: true, singleColor: HexColor(actionResponse.colorTheme?.textHighlightColor ?? "000000"))),
                    ),
                    onTap: (){
                      //Dismiss
                      pop(context);
                    }
                ) : null,
              ],
            ),
          ),
        ],
      ),
    );
  }
}
